#!/bin/bash
#--------------------------------------------------------------------------------------------------
#   mcPiDemo.sh
#
#   This script executes Nitro with a Task file that runs the "mcPi" program to estimate the value
#   of PI using the Monte Carlo method.  The program has two required parameters that are a "seed"
#   value for the random number generator and the task id, and another optional parameter that is
#   the number of iterations it performs to compute PI, which default is 1,000,000.
#
#   This script obtains a random number generator "seed" value from the nanoseconds of the current
#   time and passes the value into Nitro using the "SEED" environment variable passed by Nitro's
#   "--task-env" command line option.
#--------------------------------------------------------------------------------------------------
#   Date Written: 06 Apr 2015
#   Written by:   Gary D. Brown
#   Company:      Adaptive Computing Enterprises, Inc.
#--------------------------------------------------------------------------------------------------
#--------------------------------------------------------------------------------------------------
#   Place RM-specific job directives here
#--------------------------------------------------------------------------------------------------

#--------------------------------------------------------------------------------------------------
#   Nitro launch script location
#--------------------------------------------------------------------------------------------------
LaunchNitro="/opt/nitro/bin/launch_nitro.sh"

#--------------------------------------------------------------------------------------------------
#   Nitro Task file location can be specified by the NITRO_TASK_FILE environment variable.  If
#   there is no variable, assign a default task file.
#--------------------------------------------------------------------------------------------------
if [ -z "$NITRO_TASK_FILE" ]; then
    NITRO_TASK_FILE="$HOME/NitroTest/mcPi10K.tasks"
fi

#--------------------------------------------------------------------------------------------------
#   Identify where the job will save its output files.
#--------------------------------------------------------------------------------------------------
export NITROJOBDIR="$HOME/NitroTest"

#--------------------------------------------------------------------------------------------------
#   Create the random number generator seed value for the job run so we can pass it as a task
#   environment variable to the Nitro workers and coordinator (in case it runs a "local" worker).
#--------------------------------------------------------------------------------------------------
nsdate="`date --rfc-3339=ns`"
nanoseconds=`expr "$nsdate" : '^.*\.\(.*\)[+-].*$'`
export SEED="$nanoseconds"

#--------------------------------------------------------------------------------------------------
#   Set Nitro command line options
#
#   We have to pass environment variables dynamically created by the job script to Nitro if we want
#   them available to the Nitro tasks since not all resource managers starting Nitro workers pass
#   all environment variables to the workers.
#--------------------------------------------------------------------------------------------------
export NITRO_OPTIONS="--job-dir $NITROJOBDIR --task-env SEED=$SEED"
export NITRO_WORKER_OPTIONS=" "
export NITRO_COORD_OPTIONS=" "
export NITRO_COORD_OPTIONS="--run-local-worker $NITRO_COORD_OPTIONS"

#--------------------------------------------------------------------------------------------------
#   Run the Nitro application with the task file
#--------------------------------------------------------------------------------------------------
exec $LaunchNitro
